function [pl val] = hMKLpredict(K, model)
%
% Classification by heterogeneous multiple kernel learning
%   [pl val] = hMKLpredict(K, model)
%
% Input:
%  K - Multiple kernel matrices [n x #test x #kernel]
%  model  - Classifier model produced by `hMKLtrain.m'
%
% Output:
%  pl  - Predicted label vector {-1,+1} [#test x 1]
%  val - Classification values          [#test x 1]
%

[n, m, nK] = size(K);
X = zeros(n, nK, m);
for i = 1:nK
	X(:,i,:) = model.hinvK(:,:,i)*K(:,:,i);
end

val = squeeze(sum(sum(bsxfun(@times,X,model.W),1),2)) - model.rho;
pl  = 2*double(val>0)-1;
