function Ww = initw(y, X, parms)
%
% Initial weight by 'linear' svm
%  Ww0 = initw(y, X, params)
%
% Input:
%  y   - Label vector {-1,+1}  [n x 1]
%  X   - Feature matrices      [h x w x n]
%        NOTE: samples are given in the form of "matrix (h x w)".
%  params - Parameters [struct]
%            .C  - Balancing parameter   [scalar] (default 1)
%            .svmsolver - Linear svm solver, formed by "[alpha rho cost] = func(y,col_vectors,C)" [function_handle] (default @svmbysmo)
%						   You can give your own svm solver in this parameter field.
% 
% Output:
%  Ww0 - Initial column weight [w x r]
%
%-------------------
% BTW, random initialization is given such as by
%    Ww0 = rand(size(X,2),min(size(X,1),size(X,2)));
%    Ww0 = Ww0/sum(Ww0(:));
%
%

%- Parameters -%
if ~exist('parms', 'var') || isempty(parms), parms = struct; end
parms = parseparam(parms, 'C',1, 'svmsolver',@svmbysmo);

[h w n] = size(X);

X_ = reshape(X, h*w, n); %[h*w x n]
al = parms.svmsolver(y, X_, parms.C);
W  = reshape(X_*(al.*y), h, w); %[h x w]
[Ww S] = svd(W','econ'); S = diag(S);
nzidx = (S >= S(1)*1e-7);
Ww = bsxfun(@times, Ww(:,nzidx), sqrt(S(nzidx)'));
